pub struct InternalEventStreamCapability {
pub name: Option<String>,
pub route_metadata: Option<EventStreamRouteMetadata>,
/* private fields */
}Fields
name: Option<String>route_metadata: Option<EventStreamRouteMetadata>Trait Implementations
Sourceimpl Clone for InternalEventStreamCapability
impl Clone for InternalEventStreamCapability
Sourcefn clone(&self) -> InternalEventStreamCapability
fn clone(&self) -> InternalEventStreamCapability
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<InternalEventStreamCapability, D> for InternalEventStreamCapability
impl<D: ResourceDialect> Decode<InternalEventStreamCapability, D> for InternalEventStreamCapability
Sourceimpl Default for InternalEventStreamCapability
impl Default for InternalEventStreamCapability
Sourcefn default() -> InternalEventStreamCapability
fn default() -> InternalEventStreamCapability
Returns the “default value” for a type. Read more
Sourceimpl<D: ResourceDialect> Encode<InternalEventStreamCapability, D> for &InternalEventStreamCapability
impl<D: ResourceDialect> Encode<InternalEventStreamCapability, D> for &InternalEventStreamCapability
Sourceimpl PartialEq for InternalEventStreamCapability
impl PartialEq for InternalEventStreamCapability
Sourcefn eq(&self, other: &InternalEventStreamCapability) -> bool
fn eq(&self, other: &InternalEventStreamCapability) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TypeMarker for InternalEventStreamCapability
impl TypeMarker for InternalEventStreamCapability
Sourcetype Owned = InternalEventStreamCapability
type Owned = InternalEventStreamCapability
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for InternalEventStreamCapability
impl ValueTypeMarker for InternalEventStreamCapability
Sourcetype Borrowed<'a> = &'a InternalEventStreamCapability
type Borrowed<'a> = &'a InternalEventStreamCapability
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Persistable for InternalEventStreamCapability
impl StructuralPartialEq for InternalEventStreamCapability