pub struct RemotedAt {
pub moniker: Option<String>,
pub type_name: Option<String>,
/* private fields */
}Fields
moniker: Option<String>type_name: Option<String>Trait Implementations
Sourceimpl<D: ResourceDialect> Decode<RemotedAt, D> for RemotedAt
impl<D: ResourceDialect> Decode<RemotedAt, D> for RemotedAt
Sourceimpl TypeMarker for RemotedAt
impl TypeMarker for RemotedAt
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for RemotedAt
impl ValueTypeMarker for RemotedAt
impl Persistable for RemotedAt
impl StructuralPartialEq for RemotedAt